#!/usr/bin/env bash
set -o errexit -o nounset -o pipefail
#set -o xtrace

start() {
  local vm=debian-stretch-netinst
  local ostype=Debian_64
  local os_iso_url=https://cdimage.debian.org/cdimage/release/9.7.0/amd64/iso-cd/debian-9.7.0-amd64-netinst.iso
  local os_iso=/tmp/$(basename $os_iso_url)

  if ! test -e $os_iso; then
    curl --fail --location --create-dirs --output $os_iso-$$ $os_iso_url
    mv $os_iso-$$ $os_iso # this only happens if previous cmds succeeds (because of errexit)
  fi

  local base_dir=/tmp/vms
  local aux_base_path=/tmp/$vm/$vm-unattended-install-

  VBoxManage unregistervm $vm --delete > /dev/null || true

  rm -fr   $base_dir/$vm
  mkdir -p $base_dir/$vm

  rm -fr   $(dirname $aux_base_path)
  mkdir -p $(dirname $aux_base_path)

  VBoxManage createvm \
    --name       $vm       \
    --basefolder $base_dir \
    --ostype     $ostype   \
    --register             \

  VBoxManage modifyvm $vm \
    --memory 1024 \
    --vram   16   \

  VBoxManage storagectl $vm \
    --name        SAS \
    --add         sas \
    --portcount   1   \
    --bootable    on  \

  VBoxManage createmedium disk \
    --filename $base_dir/$vm/$vm.vdi \
    --size     8192                  \
    --format   VDI                   \

  # SAS-0-0
  VBoxManage storageattach $vm \
    --medium     $base_dir/$vm/$vm.vdi \
    --storagectl SAS                   \
    --port       0                     \
    --device     0                     \
    --type       hdd                   \

  VBoxManage storagectl $vm \
    --name        SATA \
    --add         sata \
    --portcount   1    \
    --bootable    on   \

  # SATA-0-0
  VBoxManage storageattach $vm \
    --medium     emptydrive \
    --storagectl SATA       \
    --port       0          \
    --device     0          \
    --type       dvddrive   \
    --mtype      readonly   \

  local aux_base_path=/tmp/$vm/$vm-unattended-install-

  VBoxManage unattended install $vm \
    --auxiliary-base-path $aux_base_path \
    --iso                 $os_iso        \

  if test ${fix:-0} -ne 0; then # fix isolinux-txt.cfg (isolinux/txt.cfg)
    echo "fixing ${aux_base_path}isolinux-txt.cfg"
    cp ${aux_base_path}isolinux-txt.cfg ${aux_base_path}isolinux-txt.cfg.orig

    patch ${aux_base_path}isolinux-txt.cfg < fix.patch

    diff ${aux_base_path}isolinux-txt.cfg.orig ${aux_base_path}isolinux-txt.cfg || true
  fi

  VBoxManage startvm $vm
}
start
